import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:furman_now/src/routes/index.gr.dart';
import 'package:furman_now/src/screens/home/content.dart';
import 'package:furman_now/src/screens/home/state.dart';
import 'package:provider/provider.dart';

class HomeScreen extends StatefulWidget {
  const HomeScreen({Key? key}) : super(key: key);

  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  bool _collapse = false;

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (context) => HomePageState(),
      builder: (context, _) => Scaffold(
        body: Container(
          color: const Color(0xffb7acc9),
          child: SafeArea(
            child: Container(
              color: const Color(0xffb7acc9),
              child: Stack(
                fit: StackFit.loose,
                children: [
                  const AutoTabsRouter(
                    routes: [
                      HomeRoute(),
                      StudentIdRoute(),
                    ],
                  ),
                  NotificationListener<ScrollNotification>(
                    onNotification: (notification) {
                      if (notification is ScrollUpdateNotification) {
                        final offset = notification.metrics.pixels;
                        const scrollMessageSensitivity = 20;
                        const pageSwitchSensitivity = 60;
                        if (offset < 0) {
                          var offsetAmount = offset.abs();
                          if (offsetAmount > pageSwitchSensitivity) {
                            context.router.navigate(const StudentIdRoute());
                            setState(() {
                              _collapse = true;
                            });
                          } else if (offsetAmount > scrollMessageSensitivity) {
                            if (!context.read<HomePageState>().showScrollMessage) {
                              context.read<HomePageState>().showScrollMessage = true;
                            }
                          } else {
                            if (context.read<HomePageState>().showScrollMessage) {
                              context.read<HomePageState>().showScrollMessage = false;
                            }
                          }
                        } else {
                          var offsetAmount = offset.abs();
                          if (offsetAmount > pageSwitchSensitivity) {
                            context.router.navigate(const HomeRoute());
                            setState(() {
                              _collapse = false;
                            });
                          } else {
                            if (context.read<HomePageState>().showScrollMessage) {
                              context.read<HomePageState>().showScrollMessage = false;
                            }
                          }
                        }
                      }
                      return true;
                    },
                    child: ClipRect(child: HomeContent(
                      collapse: _collapse,
                    )),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}

